@@ -19,22 +19,21 @@ from oslo_config import types
 from kolla.version import version_info as version
 
 
-BASE_OS_DISTRO = ['centos', 'rhel', 'ubuntu', 'oraclelinux', 'debian']
+BASE_OS_DISTRO = ['centos', 'rhel', 'ubuntu', 'debian']
 BASE_ARCH = ['x86_64', 'ppc64le', 'aarch64']
 DEFAULT_BASE_TAGS = {
     'centos': '7',
     'rhel': '7',
-    'oraclelinux': '7-slim',
     'debian': 'buster',
     'ubuntu': '18.04',
 }
 DISTRO_RELEASE = {
     'centos': '7',
     'rhel': '7',
-    'oraclelinux': '7',
     'debian': 'buster',
     'ubuntu': '18.04',
 }
+OPENSTACK_RELEASE = 'train'
 
 # This is noarch repository so we will use it on all architectures
 DELOREAN = \
@@ -57,6 +56,7 @@ _PROFILE_OPTS = [
                     'etcd',
                     'fluentd',
                     'haproxy',
+                    'hacluster',
                     'keepalived',
                     'kibana',
                     'kolla-toolbox',
@@ -110,12 +110,14 @@ _PROFILE_OPTS = [
                     'kuryr',
                     'magnum',
                     'manila',
+                    'masakari',
                     'mistral',
                     'monasca',
                     'murano',
                     'novajoin',
                     'octavia',
                     'panko',
+                    'qinling',
                     'rally',
                     'redis',
                     'sahara',
@@ -223,7 +225,7 @@ _CLI_OPTS = [
                      ' push properly')),
     cfg.IntOpt('retries', short='r', default=3, min=0,
                help='The number of times to retry while building'),
-    cfg.MultiOpt('regex', types.String(), positional=True, required=False,
+    cfg.MultiOpt('regex', types.String(), positional=True,
                  help=('Build only images matching regex and its'
                        ' dependencies')),
     cfg.StrOpt('registry',
@@ -266,6 +268,8 @@ _CLI_OPTS = [
                 help=('Squash the image layers. WARNING: it will consume lots'
                       ' of disk IO. "docker-squash" tool is required, install'
                       ' it by "pip install docker-squash"')),
+    cfg.StrOpt('openstack-release', default=OPENSTACK_RELEASE,
+               help='OpenStack release for building kolla-toolbox'),
 ]
 
 _BASE_OPTS = [
@@ -299,7 +303,7 @@ SOURCES = {
     'openstack-base': {
         'type': 'url',
         'location': ('$tarballs_base/requirements/'
-                     'requirements-stable-stein.tar.gz')},
+                     'requirements-stable-train.tar.gz')},
     'almanach-base': {
         'type': 'url',
         'location': ('$tarballs_base/almanach/'
@@ -307,50 +311,47 @@ SOURCES = {
     'aodh-base': {
         'type': 'url',
         'location': ('$tarballs_base/aodh/'
-                     'aodh-8.0.0.tar.gz')},
+                     'aodh-9.0.0.tar.gz')},
     'barbican-base': {
         'type': 'url',
         'location': ('$tarballs_base/barbican/'
-                     'barbican-8.0.0.tar.gz')},
+                     'barbican-9.0.0.tar.gz')},
     'bifrost-base': {
         'type': 'url',
         'location': ('$tarballs_base/bifrost/'
-                     'bifrost-6.0.4.tar.gz')},
+                     'bifrost-7.0.0.tar.gz')},
     'blazar-base': {
         'type': 'url',
         'location': ('$tarballs_base/blazar/'
-                     'blazar-3.0.0.tar.gz')},
+                     'blazar-4.0.0.tar.gz')},
     'ceilometer-base': {
         'type': 'url',
         'location': ('$tarballs_base/ceilometer/'
-                     'ceilometer-12.1.0.tar.gz')},
+                     'ceilometer-13.0.0.tar.gz')},
     'ceilometer-base-plugin-panko': {
         'type': 'url',
         'location': ('$tarballs_base/panko/'
-                     'panko-6.0.0.tar.gz')},
+                     'panko-7.0.0.tar.gz')},
     'cinder-base': {
         'type': 'url',
         'location': ('$tarballs_base/cinder/'
-                     'cinder-14.1.0.tar.gz')},
+                     'cinder-15.0.0.tar.gz')},
     'congress-base': {
         'type': 'url',
         'location': ('$tarballs_base/congress/'
-                     'openstack-congress-9.0.0.tar.gz')},
+                     'openstack-congress-10.0.0.tar.gz')},
     'cloudkitty-base': {
         'type': 'url',
         'location': ('$tarballs_base/cloudkitty/'
-                     'cloudkitty-9.0.0.tar.gz')},
-    'crane': {
-        'type': 'url',
-        'location': ('https://github.com/pulp/crane/archive/3.3.0.tar.gz')},
+                     'cloudkitty-11.0.1.tar.gz')},
     'cyborg-base': {
         'type': 'url',
         'location': ('$tarballs_base/cyborg/'
-                     'openstack-cyborg-2.0.0.tar.gz')},
+                     'openstack-cyborg-3.0.0.tar.gz')},
     'designate-base': {
         'type': 'url',
         'location': ('$tarballs_base/designate/'
-                     'designate-8.0.0.tar.gz')},
+                     'designate-9.0.0.tar.gz')},
     'dragonflow-base': {
         'type': 'url',
         'location': ('$tarballs_base/dragonflow/'
@@ -358,19 +359,19 @@ SOURCES = {
     'ec2-api': {
         'type': 'url',
         'location': ('$tarballs_base/ec2-api/'
-                     'ec2-api-8.0.0.tar.gz')},
+                     'ec2-api-9.0.0.tar.gz')},
     'freezer-api': {
         'type': 'url',
         'location': ('$tarballs_base/freezer-api/'
-                     'freezer-api-7.1.0.tar.gz')},
+                     'freezer-api-7.2.0.tar.gz')},
     'freezer-base': {
         'type': 'url',
         'location': ('$tarballs_base/freezer/'
-                     'freezer-7.1.0.tar.gz')},
+                     'freezer-7.2.0.tar.gz')},
     'glance-base': {
         'type': 'url',
         'location': ('$tarballs_base/glance/'
-                     'glance-18.0.1.tar.gz')},
+                     'glance-19.0.0.tar.gz')},
     'gnocchi-base': {
         'type': 'git',
         'reference': '4.3.4',
@@ -379,204 +380,216 @@ SOURCES = {
     'heat-base': {
         'type': 'url',
         'location': ('$tarballs_base/heat/'
-                     'openstack-heat-12.1.0.tar.gz')},
+                     'openstack-heat-13.0.0.tar.gz')},
     'horizon': {
         'type': 'url',
         'location': ('$tarballs_base/horizon/'
-                     'horizon-15.3.0.tar.gz')},
+                     'horizon-16.0.0.tar.gz')},
     'horizon-plugin-blazar-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/blazar-dashboard/'
-                     'blazar-dashboard-1.3.0.tar.gz')},
+                     'blazar-dashboard-2.0.0.tar.gz')},
     'horizon-plugin-congress-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/congress-dashboard/'
-                     'congress-dashboard-4.0.0.tar.gz')},
+                     'congress-dashboard-5.0.0.tar.gz')},
     'horizon-plugin-cloudkitty-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/cloudkitty-dashboard/'
-                     'cloudkitty-dashboard-8.1.0.tar.gz')},
+                     'cloudkitty-dashboard-9.0.0.tar.gz')},
     'horizon-plugin-designate-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/designate-dashboard/'
-                     'designate-dashboard-8.0.0.tar.gz')},
+                     'designate-dashboard-9.0.0.tar.gz')},
     'horizon-plugin-fwaas-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-fwaas-dashboard/'
-                     'neutron-fwaas-dashboard-2.0.2.tar.gz')},
+                     'neutron-fwaas-dashboard-2.1.0.tar.gz')},
     'horizon-plugin-freezer-web-ui': {
         'type': 'url',
         'location': ('$tarballs_base/freezer-web-ui/'
-                     'freezer-web-ui-7.1.0.tar.gz')},
+                     'freezer-web-ui-7.2.0.tar.gz')},
     'horizon-plugin-heat-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/heat-dashboard/'
-                     'heat-dashboard-1.5.0.tar.gz')},
+                     'heat-dashboard-2.0.0.tar.gz')},
     'horizon-plugin-ironic-ui': {
         'type': 'url',
         'location': ('$tarballs_base/ironic-ui/'
-                     'ironic-ui-3.4.1.tar.gz')},
+                     'ironic-ui-3.5.3.tar.gz')},
     'horizon-plugin-karbor-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/karbor-dashboard/'
-                     'karbor-dashboard-1.2.1.tar.gz')},
+                     'karbor-dashboard-1.3.0.tar.gz')},
     'horizon-plugin-magnum-ui': {
         'type': 'url',
         'location': ('$tarballs_base/magnum-ui/'
-                     'magnum-ui-5.1.0.tar.gz')},
+                     'magnum-ui-5.2.1.tar.gz')},
     'horizon-plugin-manila-ui': {
         'type': 'url',
         'location': ('$tarballs_base/manila-ui/'
-                     'manila-ui-2.18.1.tar.gz')},
+                     'manila-ui-2.19.1.tar.gz')},
+    'horizon-plugin-masakari-dashboard': {
+        'type': 'url',
+        'location': ('$tarballs_base/masakari-dashboard/'
+                     'masakari-dashboard-1.0.0.tar.gz')},
     'horizon-plugin-mistral-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/mistral-dashboard/'
-                     'mistral-dashboard-8.1.0.tar.gz')},
+                     'mistral-dashboard-9.0.0.tar.gz')},
     'horizon-plugin-monasca-ui': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-ui/'
-                     'monasca-ui-1.15.0.tar.gz')},
+                     'monasca-ui-1.17.0.tar.gz')},
     'horizon-plugin-murano-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/murano-dashboard/'
-                     'murano-dashboard-7.0.0.tar.gz')},
-    'horizon-plugin-neutron-lbaas-dashboard': {
-        'type': 'url',
-        'location': ('$tarballs_base/neutron-lbaas-dashboard/'
-                     'neutron-lbaas-dashboard-6.0.0.tar.gz')},
+                     'murano-dashboard-8.0.0.tar.gz')},
     'horizon-plugin-neutron-vpnaas-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-vpnaas-dashboard/'
-                     'neutron-vpnaas-dashboard-1.5.2.tar.gz')},
+                     'neutron-vpnaas-dashboard-1.6.0.tar.gz')},
     'horizon-plugin-octavia-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/octavia-dashboard/'
-                     'octavia-dashboard-3.0.1.tar.gz')},
+                     'octavia-dashboard-4.0.0.tar.gz')},
+    'horizon-plugin-qinling-dashboard': {
+        'type': 'url',
+        'location': ('$tarballs_base/qinling-dashboard/'
+                     'qinling-dashboard-2.0.0.tar.gz')},
     'horizon-plugin-sahara-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/sahara-dashboard/'
-                     'sahara-dashboard-10.0.1.tar.gz')},
+                     'sahara-dashboard-11.0.0.tar.gz')},
     'horizon-plugin-searchlight-ui': {
         'type': 'url',
         'location': ('$tarballs_base/searchlight-ui/'
-                     'searchlight-ui-6.0.0.tar.gz')},
+                     'searchlight-ui-7.0.0.tar.gz')},
     'horizon-plugin-senlin-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/senlin-dashboard/'
-                     'senlin-dashboard-0.10.1.tar.gz')},
+                     'senlin-dashboard-0.11.0.tar.gz')},
     'horizon-plugin-solum-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/solum-dashboard/'
-                     'solum-dashboard-2.6.0.tar.gz')},
+                     'solum-dashboard-3.0.0.tar.gz')},
     'horizon-plugin-tacker-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/tacker-horizon/'
-                     'tacker-horizon-0.14.0.tar.gz')},
+                     'tacker-horizon-0.15.0.tar.gz')},
     'horizon-plugin-trove-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/trove-dashboard/'
-                     'trove-dashboard-12.0.0.tar.gz')},
+                     'trove-dashboard-13.0.0.tar.gz')},
     'horizon-plugin-vitrage-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/vitrage-dashboard/'
-                     'vitrage-dashboard-1.9.1.tar.gz')},
+                     'vitrage-dashboard-2.0.0.tar.gz')},
     'horizon-plugin-watcher-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/watcher-dashboard/'
-                     'watcher-dashboard-1.12.0.tar.gz')},
+                     'watcher-dashboard-2.0.0.tar.gz')},
     'horizon-plugin-zaqar-ui': {
         'type': 'url',
         'location': ('$tarballs_base/zaqar-ui/'
-                     'zaqar-ui-6.0.0.tar.gz')},
+                     'zaqar-ui-7.0.0.tar.gz')},
     'horizon-plugin-zun-ui': {
         'type': 'url',
         'location': ('$tarballs_base/zun-ui/'
-                     'zun-ui-3.0.1.tar.gz')},
+                     'zun-ui-4.0.0.tar.gz')},
     'ironic-base': {
         'type': 'url',
         'location': ('$tarballs_base/ironic/'
-                     'ironic-12.1.4.tar.gz')},
+                     'ironic-13.0.2.tar.gz')},
     'ironic-inspector': {
         'type': 'url',
         'location': ('$tarballs_base/ironic-inspector/'
-                     'ironic-inspector-8.2.4.tar.gz')},
+                     'ironic-inspector-9.2.0.tar.gz')},
     'karbor-base': {
         'type': 'url',
         'location': ('$tarballs_base/karbor/'
-                     'karbor-1.3.0.tar.gz')},
+                     'karbor-1.4.0.tar.gz')},
     'keystone-base': {
         'type': 'url',
         'location': ('$tarballs_base/keystone/'
-                     'keystone-15.0.1.tar.gz')},
+                     'keystone-16.0.0.tar.gz')},
     'kuryr-base': {
         'type': 'url',
         'location': ('$tarballs_base/kuryr/'
-                     'kuryr-lib-0.9.0.tar.gz')},
+                     'kuryr-lib-1.1.1.tar.gz')},
     'kuryr-libnetwork': {
         'type': 'url',
         'location': ('$tarballs_base/kuryr-libnetwork/'
-                     'kuryr-libnetwork-3.0.0.tar.gz')},
+                     'kuryr-libnetwork-4.0.0.tar.gz')},
     'magnum-base': {
         'type': 'url',
         'location': ('$tarballs_base/magnum/'
-                     'magnum-8.2.0.tar.gz')},
+                     'magnum-9.1.0.tar.gz')},
     'manila-base': {
         'type': 'url',
         'location': ('$tarballs_base/manila/'
-                     'manila-8.1.2.tar.gz')},
+                     'manila-9.1.0.tar.gz')},
+    'masakari-base': {
+        'type': 'url',
+        'location': ('$tarballs_base/masakari/'
+                     'masakari-8.0.0.tar.gz')},
+    'masakari-monitors': {
+        'type': 'url',
+        'location': ('$tarballs_base/masakari-monitors/'
+                     'masakari-monitors-8.0.0.tar.gz')},
     'mistral-base': {
         'type': 'url',
         'location': ('$tarballs_base/mistral/'
-                     'mistral-8.1.0.tar.gz')},
+                     'mistral-9.0.1.tar.gz')},
     'mistral-base-plugin-tacker': {
         'type': 'url',
         'location': ('$tarballs_base/tacker/'
-                     'tacker-1.0.0.tar.gz')},
+                     'tacker-2.0.0.tar.gz')},
     'monasca-agent': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-agent/'
-                     'monasca-agent-2.10.0.tar.gz')},
+                     'monasca-agent-2.11.0.tar.gz')},
     'monasca-api': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-api/'
-                     'monasca-api-3.0.0.tar.gz')},
+                     'monasca-api-3.1.0.tar.gz')},
     'monasca-log-api': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-log-api/'
-                     'monasca-log-api-2.9.0.tar.gz')},
+                     'monasca-log-api-2.10.0.tar.gz')},
     'monasca-notification': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-notification/'
-                     'monasca-notification-1.17.0.tar.gz')},
+                     'monasca-notification-1.18.0.tar.gz')},
     'monasca-persister': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-persister/'
-                     'monasca-persister-1.14.0.tar.gz')},
+                     'monasca-persister-1.15.0.tar.gz')},
     'monasca-statsd': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-statsd/'
-                     'monasca-statsd-1.11.0.tar.gz')},
+                     'monasca-statsd-1.12.0.tar.gz')},
     # FIXME(dszumski): Use openstack tar when infra is fixed
     'monasca-thresh': {
         'type': 'url',
         'location': ('https://github.com/openstack/monasca-thresh/archive/'
-                     '2.3.0.tar.gz')},
+                     'master.tar.gz')},
     'monasca-thresh-additions-monasca-common': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-common/'
-                     'monasca-common-2.13.0.tar.gz')},
+                     'monasca-common-2.16.1.tar.gz')},
     'murano-base': {
         'type': 'url',
         'location': ('$tarballs_base/murano/'
-                     'murano-7.0.0.tar.gz')},
+                     'murano-8.0.0.tar.gz')},
     'neutron-base': {
         'type': 'url',
         'location': ('$tarballs_base/neutron/'
-                     'neutron-14.2.0.tar.gz')},
+                     'neutron-15.0.0.tar.gz')},
     'neutron-base-plugin-neutron-fwaas': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-fwaas/'
-                     'neutron-fwaas-14.0.1.tar.gz')},
+                     'neutron-fwaas-15.0.0.tar.gz')},
     'neutron-base-plugin-networking-ansible': {
         'type': 'url',
         'location': ('$tarballs_base/networking-ansible/'
@@ -584,15 +597,15 @@ SOURCES = {
     'neutron-base-plugin-networking-baremetal': {
         'type': 'url',
         'location': ('$tarballs_base/networking-baremetal/'
-                     'networking-baremetal-1.3.0.tar.gz')},
+                     'networking-baremetal-1.4.0.tar.gz')},
     'neutron-base-plugin-networking-generic-switch': {
         'type': 'url',
         'location': ('$tarballs_base/networking-generic-switch/'
-                     'networking-generic-switch-1.3.1.tar.gz')},
+                     'networking-generic-switch-2.1.0.tar.gz')},
     'neutron-base-plugin-networking-sfc': {
         'type': 'url',
         'location': ('$tarballs_base/networking-sfc/'
-                     'networking-sfc-8.0.0.tar.gz')},
+                     'networking-sfc-9.0.0.tar.gz')},
     'neutron-base-plugin-vmware-nsx': {
         'type': 'url',
         'location': ('$tarballs_base/vmware-nsx/'
@@ -600,263 +613,255 @@ SOURCES = {
     'neutron-base-plugin-vpnaas-agent': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-vpnaas/'
-                     'neutron-vpnaas-14.0.1.tar.gz')},
+                     'neutron-vpnaas-15.0.0.tar.gz')},
     'neutron-bgp-dragent': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-dynamic-routing/'
-                     'neutron-dynamic-routing-14.0.0.tar.gz')},
-    'neutron-lbaas-agent': {
-        'type': 'url',
-        'location': ('$tarballs_base/neutron-lbaas/'
-                     'neutron-lbaas-14.0.1.tar.gz')},
+                     'neutron-dynamic-routing-15.0.0.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-odl': {
         'type': 'url',
         'location': ('$tarballs_base/networking-odl/'
-                     'networking-odl-14.0.1.tar.gz')},
+                     'networking-odl-15.0.0.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-bgpvpn': {
         'type': 'url',
         'location': ('$tarballs_base/networking-bgpvpn/'
-                     'networking-bgpvpn-10.0.0.tar.gz')},
+                     'networking-bgpvpn-11.0.0.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-l2gw': {
         'type': 'url',
         'location': ('$tarballs_base/networking-l2gw/'
-                     'networking-l2gw-14.0.0.tar.gz')},
+                     'networking-l2gw-15.0.0.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-sfc': {
         'type': 'url',
         'location': ('$tarballs_base/networking-sfc/'
-                     'networking-sfc-8.0.0.tar.gz')},
-    'neutron-server-plugin-networking-infoblox': {
-        'type': 'url',
-        'location': ('$tarballs_base/networking-infoblox/'
-                     'networking-infoblox-12.0.0.tar.gz')},
+                     'networking-sfc-9.0.0.tar.gz')},
     'neutron-server-plugin-neutron-dynamic-routing': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-dynamic-routing/'
-                     'neutron-dynamic-routing-14.0.0.tar.gz')},
-    'neutron-server-plugin-neutron-lbaas': {
-        'type': 'url',
-        'location': ('$tarballs_base/neutron-lbaas/'
-                     'neutron-lbaas-14.0.1.tar.gz')},
+                     'neutron-dynamic-routing-15.0.0.tar.gz')},
     'neutron-server-plugin-vmware-nsxlib': {
         'type': 'url',
         'location': ('$tarballs_base/vmware-nsxlib/'
-                     'vmware-nsxlib-13.1.0.tar.gz')},
+                     'vmware-nsxlib-14.0.3.tar.gz')},
     'neutron-vpnaas-agent': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-vpnaas/'
-                     'neutron-vpnaas-14.0.1.tar.gz')},
+                     'neutron-vpnaas-15.0.0.tar.gz')},
     'neutron-server-ovn-plugin-networking-ovn': {
         'type': 'url',
         'location': ('$tarballs_base/networking-ovn/'
-                     'networking-ovn-6.1.0.tar.gz')},
+                     'networking-ovn-7.0.0.tar.gz')},
     'neutron-metadata-agent-ovn-plugin-networking-ovn': {
         'type': 'url',
         'location': ('$tarballs_base/networking-ovn/'
-                     'networking-ovn-6.1.0.tar.gz')},
+                     'networking-ovn-7.0.0.tar.gz')},
     'nova-base': {
         'type': 'url',
         'location': ('$tarballs_base/nova/'
-                     'nova-19.2.0.tar.gz')},
+                     'nova-20.0.1.tar.gz')},
     'nova-base-plugin-blazar': {
         'type': 'url',
         'location': ('$tarballs_base/blazar-nova/'
-                     'blazar-nova-1.2.0.tar.gz')},
+                     'blazar-nova-1.3.0.tar.gz')},
     'nova-base-plugin-mksproxy': {
         'type': 'url',
         'location': ('$tarballs_base/nova-mksproxy/'
-                     'nova-mksproxy-master.tar.gz')},
+                     'nova-mksproxy-0.0.2.tar.gz')},
     'novajoin-base': {
         'type': 'url',
         'location': ('$tarballs_base/novajoin/'
-                     'novajoin-1.1.1.tar.gz')},
+                     'novajoin-1.2.0.tar.gz')},
     'octavia-base': {
         'type': 'url',
         'location': ('$tarballs_base/octavia/'
-                     'octavia-4.1.2.tar.gz')},
+                     'octavia-5.0.0.tar.gz')},
     'panko-base': {
         'type': 'url',
         'location': ('$tarballs_base/panko/'
-                     'panko-6.0.0.tar.gz')},
+                     'panko-7.0.0.tar.gz')},
     'placement-base': {
         'type': 'url',
         'location': ('$tarballs_base/placement/'
-                     'openstack-placement-1.1.0.tar.gz')},
+                     'openstack-placement-2.0.0.tar.gz')},
+    'qinling-base': {
+        'type': 'url',
+        'location': ('$tarballs_base/qinling/'
+                     'qinling-3.0.0.tar.gz')},
     'tempest-plugin-tempest-conf': {
         'type': 'url',
         'location': ('$tarballs_base/python-tempestconf/'
-                     'python-tempestconf-2.1.0.tar.gz')},
+                     'python-tempestconf-2.3.0.tar.gz')},
     'tempest-plugin-barbican': {
         'type': 'url',
         'location': ('$tarballs_base/barbican-tempest-plugin/'
-                     'barbican_tempest_plugin-0.2.0.tar.gz')},
+                     'barbican_tempest_plugin-0.3.0.tar.gz')},
     'tempest-plugin-blazar': {
         'type': 'url',
         'location': ('$tarballs_base/blazar-tempest-plugin/'
-                     'blazar_tempest_plugin-0.2.0.tar.gz')},
+                     'blazar_tempest_plugin-0.3.0.tar.gz')},
     'tempest-plugin-cinder': {
         'type': 'url',
         'location': ('$tarballs_base/cinder-tempest-plugin/'
-                     'cinder_tempest_plugin-0.2.0.tar.gz')},
+                     'cinder-tempest-plugin-0.3.0.tar.gz')},
     'tempest-plugin-congress': {
         'type': 'url',
         'location': ('$tarballs_base/congress-tempest-plugin/'
-                     'congress-tempest-plugin-0.2.0.tar.gz')},
+                     'congress-tempest-plugin-0.3.0.tar.gz')},
     'tempest-plugin-ec2api': {
         'type': 'url',
         'location': ('$tarballs_base/ec2api-tempest-plugin/'
-                     'ec2api-tempest-plugin-0.2.0.tar.gz')},
+                     'ec2api-tempest-plugin-0.3.0.tar.gz')},
     'tempest-plugin-heat': {
         'type': 'url',
         'location': ('$tarballs_base/heat-tempest-plugin/'
-                     'heat-tempest-plugin-0.3.0.tar.gz')},
+                     'heat-tempest-plugin-0.4.0.tar.gz')},
     'tempest-plugin-ironic': {
         'type': 'url',
         'location': ('$tarballs_base/ironic-tempest-plugin/'
-                     'ironic-tempest-plugin-1.3.0.tar.gz')},
+                     'ironic-tempest-plugin-1.5.1.tar.gz')},
     'tempest-plugin-keystone': {
         'type': 'url',
         'location': ('$tarballs_base/keystone-tempest-plugin/'
-                     'keystone_tempest_plugin-0.2.0.tar.gz')},
+                     'keystone_tempest_plugin-0.3.0.tar.gz')},
     'tempest-plugin-magnum': {
         'type': 'url',
         'location': ('$tarballs_base/magnum-tempest-plugin/'
-                     'magnum_tempest_plugin-0.2.0.tar.gz')},
+                     'magnum_tempest_plugin-0.3.0.tar.gz')},
     'tempest-plugin-manila': {
         'type': 'url',
         'location': ('$tarballs_base/manila-tempest-plugin/'
-                     'manila-tempest-plugin-0.3.0.tar.gz')},
+                     'manila-tempest-plugin-0.4.1.tar.gz')},
     'tempest-plugin-mistral': {
         'type': 'url',
         'location': ('$tarballs_base/mistral-tempest-plugin/'
-                     'mistral_tempest_tests-0.2.0.tar.gz')},
+                     'mistral_tempest_tests-0.3.0.tar.gz')},
     'tempest-plugin-monasca': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-tempest-plugin/'
-                     'monasca-tempest-plugin-1.0.0.tar.gz')},
+                     'monasca-tempest-plugin-1.1.0.tar.gz')},
     'tempest-plugin-murano': {
         'type': 'url',
         'location': ('$tarballs_base/murano-tempest-plugin/'
-                     'murano-tempest-plugin-1.0.0.tar.gz')},
+                     'murano-tempest-plugin-1.1.0.tar.gz')},
     'tempest-plugin-neutron': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-tempest-plugin/'
-                     'neutron-tempest-plugin-0.3.0.tar.gz')},
+                     'neutron-tempest-plugin-0.6.0.tar.gz')},
     'tempest-plugin-patrole': {
         'type': 'url',
         'location': ('$tarballs_base/patrole/'
-                     'patrole-0.5.0.tar.gz')},
+                     'patrole-0.7.0.tar.gz')},
     'tempest-plugin-telemetry': {
         'type': 'url',
         'location': ('$tarballs_base/telemetry-tempest-plugin/'
-                     'telemetry_tempest_plugin-0.3.0.tar.gz')},
+                     'telemetry_tempest_plugin-0.4.0.tar.gz')},
+    'tempest-plugin-tripleo-common': {
+        'type': 'url',
+        'location': ('$tarballs_base/tripleo-common-tempest-plugin/'
+                     'tripleo-common-tempest-plugin-master.tar.gz')},
     'tempest-plugin-trove': {
         'type': 'url',
         'location': ('$tarballs_base/trove-tempest-plugin/'
-                     'trove_tempest_plugin-0.2.0.tar.gz')},
+                     'trove_tempest_plugin-0.3.0.tar.gz')},
     'tempest-plugin-vitrage': {
         'type': 'url',
         'location': ('$tarballs_base/vitrage-tempest-plugin/'
-                     'vitrage-tempest-plugin-2.2.1.tar.gz')},
+                     'vitrage-tempest-plugin-3.0.0.tar.gz')},
     'tempest-plugin-watcher': {
         'type': 'url',
         'location': ('$tarballs_base/watcher-tempest-plugin/'
-                     'watcher-tempest-plugin-1.1.0.tar.gz')},
+                     'watcher-tempest-plugin-1.2.0.tar.gz')},
     'tempest-plugin-zaqar': {
         'type': 'url',
         'location': ('$tarballs_base/zaqar-tempest-plugin/'
-                     'zaqar_tempest_plugin-0.2.0.tar.gz')},
+                     'zaqar_tempest_plugin-0.3.0.tar.gz')},
     'rally': {
         'type': 'url',
         'location': ('$tarballs_base/rally/'
-                     'rally-1.4.1.tar.gz')},
+                     'rally-2.0.0.tar.gz')},
     'sahara-base': {
         'type': 'url',
         'location': ('$tarballs_base/sahara/'
-                     'sahara-10.0.1.tar.gz')},
+                     'sahara-11.0.0.tar.gz')},
     'sahara-base-plugin-ambari': {
         'type': 'url',
         'location': ('$tarballs_base/sahara-plugin-ambari/'
-                     'sahara-plugin-ambari-1.0.0.tar.gz')},
+                     'sahara-plugin-ambari-2.0.0.tar.gz')},
     'sahara-base-plugin-cdh': {
         'type': 'url',
         'location': ('$tarballs_base/sahara-plugin-cdh/'
-                     'sahara-plugin-cdh-1.0.1.tar.gz')},
+                     'sahara-plugin-cdh-2.0.0.tar.gz')},
     'sahara-base-plugin-mapr': {
         'type': 'url',
         'location': ('$tarballs_base/sahara-plugin-mapr/'
-                     'sahara-plugin-mapr-1.0.1.tar.gz')},
+                     'sahara-plugin-mapr-2.0.0.tar.gz')},
     'sahara-base-plugin-spark': {
         'type': 'url',
         'location': ('$tarballs_base/sahara-plugin-spark/'
-                     'sahara-plugin-spark-1.0.0.tar.gz')},
+                     'sahara-plugin-spark-2.0.0.tar.gz')},
     'sahara-base-plugin-storm': {
         'type': 'url',
         'location': ('$tarballs_base/sahara-plugin-storm/'
-                     'sahara-plugin-storm-1.0.0.tar.gz')},
+                     'sahara-plugin-storm-2.0.0.tar.gz')},
     'sahara-base-plugin-vanilla': {
         'type': 'url',
         'location': ('$tarballs_base/sahara-plugin-vanilla/'
-                     'sahara-plugin-vanilla-1.0.0.tar.gz')},
+                     'sahara-plugin-vanilla-2.0.0.tar.gz')},
     'searchlight-base': {
         'type': 'url',
         'location': ('$tarballs_base/searchlight/'
-                     'searchlight-6.0.0.tar.gz')},
+                     'searchlight-7.0.0.tar.gz')},
     'senlin-base': {
         'type': 'url',
         'location': ('$tarballs_base/senlin/'
-                     'senlin-7.0.0.tar.gz')},
+                     'senlin-8.0.0.tar.gz')},
     'solum-base': {
         'type': 'url',
         'location': ('$tarballs_base/solum/'
-                     'solum-6.0.0.tar.gz')},
+                     'solum-7.0.0.tar.gz')},
     'swift-base': {
         'type': 'url',
         'location': ('$tarballs_base/swift/'
-                     'swift-2.21.1.tar.gz')},
+                     'swift-2.23.1.tar.gz')},
     'tacker-base': {
         'type': 'url',
         'location': ('$tarballs_base/tacker/'
-                     'tacker-1.0.0.tar.gz')},
+                     'tacker-2.0.0.tar.gz')},
     'tacker-base-plugin-networking-sfc': {
         'type': 'url',
         'location': ('$tarballs_base/networking-sfc/'
-                     'networking-sfc-8.0.0.tar.gz')},
+                     'networking-sfc-9.0.0.tar.gz')},
     'tempest': {
         'type': 'url',
         'location': ('$tarballs_base/tempest/'
-                     'tempest-20.0.0.tar.gz')},
+                     'tempest-22.1.0.tar.gz')},
     'tripleoclient': {
         'type': 'url',
         'location': ('$tarballs_base/python-tripleoclient/'
-                     'tripleoclient-11.3.0.tar.gz')},
-    'tripleo-ui': {
-        'type': 'url',
-        'location': ('$tarballs_base/tripleo-ui/'
-                     'tripleo-ui-10.3.0.tar.gz')},
+                     'tripleoclient-12.3.0.tar.gz')},
     'trove-base': {
         'type': 'url',
         'location': ('$tarballs_base/trove/'
-                     'trove-11.0.0.tar.gz')},
+                     'trove-12.0.0.tar.gz')},
     'vitrage-base': {
         'type': 'url',
         'location': ('$tarballs_base/vitrage/'
-                     'vitrage-4.3.1.tar.gz')},
+                     'vitrage-5.0.1.tar.gz')},
     'vmtp': {
         'type': 'url',
         'location': ('$tarballs_base/vmtp/'
-                     'vmtp-2.5.0.tar.gz')},
+                     'vmtp-master.tar.gz')},
     'watcher-base': {
         'type': 'url',
         'location': ('$tarballs_base/watcher/'
-                     'python-watcher-2.0.0.tar.gz')},
+                     'python-watcher-3.0.0.tar.gz')},
     'zaqar-base': {
         'type': 'url',
         'location': ('$tarballs_base/zaqar/'
-                     'zaqar-8.0.0.tar.gz')},
+                     'zaqar-9.0.0.tar.gz')},
     'zun-base': {
         'type': 'url',
         'location': ('$tarballs_base/zun/'
-                     'zun-3.0.0.tar.gz')}
+                     'zun-4.0.0.tar.gz')}
 }
 
 
@@ -1186,6 +1191,14 @@ USERS = {
     'cyborg-user': {
         'uid': 42483,
         'gid': 42483,
+    },
+    'qinling-user': {
+        'uid': 42484,
+        'gid': 42484,
+    },
+    'masakari-user': {
+        'uid': 42485,
+        'gid': 42485,
     }
 }
 
