@@ -71,14 +71,44 @@ STATUS_UNMATCHED = 'unmatched'
 STATUS_MATCHED = 'matched'
 STATUS_UNPROCESSED = 'unprocessed'
 STATUS_SKIPPED = 'skipped'
+STATUS_UNBUILDABLE = 'unbuildable'
 
 # All error status constants.
 STATUS_ERRORS = (STATUS_CONNECTION_ERROR, STATUS_PUSH_ERROR,
                  STATUS_ERROR, STATUS_PARENT_ERROR)
 
+# The dictionary of unbuildable images supports keys in the format:
+# '<distro>+<installation_type>+<arch>' where each component is optional
+# and can be omitted along with the + separator which means that component
+# is irrelevant. Otherwise all must match for skip to happen.
+UNBUILDABLE_IMAGES = {
+    'aarch64': {
+        "cyborg-base",       # no binary package
+        "kibana",            # no binary package
+        "monasca-grafana",   # no phantomJS on aarch64
+        "opendaylight",      # no binary package
+        "prometheus-mtail",  # no aarch64 binary
+        "telegraf",          # no binary package
+    },
 
-SKIPPED_IMAGES = {
-    'centos+binary': [
+    'ppc64le': {
+        "cyborg-base",       # no binary package
+        "elasticsearch",     # no binary package
+        "grafana",           # no binary package
+        "kibana",            # no binary package
+        "kube-proxy",        # no binary
+        "helm-repository",   # no binary
+        "monasca-grafana",   # no phantomJS
+        "opendaylight",      # no binary package
+        "prometheus-base",   # no ppc64le binaries
+        "telegraf",          # no binary package
+        "xtrabackup",        # no binary package
+    },
+
+    'source': {
+        "tripleoclient",
+    },
+    'binary': {
         "almanach-base",
         "bifrost-base",
         "blazar-base",
@@ -87,140 +117,105 @@ SKIPPED_IMAGES = {
         "freezer-base",
         "karbor-base",
         "kuryr-base",
+        "masakari-base",
         "monasca-base",
         "monasca-thresh",
-        "mongodb",
         "nova-mksproxy",
-        "ovsdpdk",
+        "qinling-base",
         "searchlight-base",
         "solum-base",
         "vmtp",
         "zun-base",
-    ],
-    'centos+source': [
-        "mongodb",
-        "ovsdpdk",
-        "tripleoclient",
-        # TODO(jeffrey4l): remove tripleo-ui when following bug is fixed
-        # https://bugs.launchpad.net/tripleo/+bug/1744215
-        "tripleo-ui",
-    ],
-    'ubuntu+binary': [
-        "almanach-base",
-        "bifrost-base",
-        "blazar-base",
-        "cloudkitty-base",
-        "congress-base",
-        "crane",
-        "cyborg-base",
-        "dragonflow-base",
-        "ec2-api",
-        "freezer-base",
-        "heat-all",
-        "ironic-neutron-agent",
-        "karbor-base",
-        "kuryr-base",
-        "mistral-event-engine",
-        "monasca-base",
-        "monasca-thresh",
-        "nova-mksproxy",
-        "novajoin-base",
-        # There is no qdrouterd package for ubuntu bionic
-        "qdrouterd",
-        "searchlight-base",
-        "solum-base",
-        "tacker-base",
-        "tripleoclient",
-        "tripleo-ui",
-        "vitrage-base",
-        "vmtp",
-        "zaqar",
-        "zun-base",
-    ],
-    'ubuntu+source': [
-        # FIXME(yoctozepto): temporary block due to upstream issues
-        "bifrost-base",
+    },
 
-        "crane",
+    'source+aarch64': {
+        "monasca-base",  # pypi 'confluent-kafka' requires newer libfdkafka-dev
+                         # than distributions have
+        "tempest",       # same reason as 'monasca-base'
+    },
+
+    'source+ppc64le': {
+        "monasca-base",  # pypi 'confluent-kafka' requires newer libfdkafka-dev
+                         # than distributions have
+        "tempest",       # same reason as 'monasca-base'
+    },
+
+    'centos': {
+        "ovsdpdk",
+    },
+    'debian': {
+        "bifrost-base",  # tries to install 'mysql-server' which is not in
+                         # Debian 'buster'
         "cyborg-base",
-        # There is no qdrouterd package for ubuntu bionic
+        "monasca-grafana",  # FIXME(hrw): some ssl issues to fix
+        "mongodb",
+        "opendaylight",  # no binary package
+        "ovsdpdk",
         "qdrouterd",
-        "tripleoclient",
-        # TODO(jeffrey4l): remove tripleo-ui when following bug is fixed
-        # https://bugs.launchpad.net/tripleo/+bug/1744215
-        "tripleo-ui"
-    ],
-    'debian+binary': [
-        "almanach-base",
-        "bifrost-base",
-        "blazar-base",
-        "cloudkitty-base",
-        "congress-base",
-        "crane",
+        "sensu-base",
+        "telegraf",      # no binary package
+    },
+    'ubuntu': {
         "cyborg-base",
-        "dragonflow-base",
+        "qdrouterd",  # There is no qdrouterd package for ubuntu bionic
+    },
+
+    'debian+aarch64': {
+        "skydive-base",  # no binary package
+    },
+    'ubuntu+aarch64': {
+        "sensu-base",    # no binary package
+        "skydive-base",  # no binary package
+    },
+
+    'debian+ppc64le': {
+        "skydive-base",  # no binary package
+    },
+    'ubuntu+ppc64le': {
+        "sensu-base",    # no binary package
+        "skydive-base",  # no binary package
+    },
+
+    'centos+aarch64': {
+        "elasticsearch",  # no binary package
+        "hacluster-pcs",  # no binary package
+        "influxdb",       # no binary package
+        "mongodb",        # no binary package
+    },
+
+    'centos+ppc64le': {
+        "hacluster-pcs",  # no binary package
+        "influxdb",       # no binary package
+        "mongodb",        # no binary package
+    },
+
+    'debian+binary': {
+        "cloudkitty-base",
         "ec2-api",
-        "freezer-base",
         "heat-all",
         "ironic-neutron-agent",
-        "karbor-base",
-        "kuryr-base",
-        "mistral-event-engine",
-        "monasca-base",
-        "monasca-thresh",
-        "nova-mksproxy",
+        "neutron-server-opendaylight",
+        "nova-serialproxy",
         "novajoin-base",
-        "octavia-base",
-        "searchlight-base",
-        "sensu-base",
-        "solum-base",
         "tacker-base",
         "tripleoclient",
-        "tripleo-ui",
+        "trove-base",
+        "vitrage-base",
+    },
+
+    'ubuntu+binary': {
+        "cloudkitty-base",
+        "congress-base",
+        "ec2-api",
+        "heat-all",
+        "ironic-neutron-agent",
+        "novajoin-base",
+        "rally",
+        "tacker-base",
+        "tripleoclient",
         "vitrage-base",
-        "vmtp",
         "zaqar",
-        "zun-base"
-    ],
-    'debian+source': [
-        "crane",
-        "cyborg-base",
-        "sensu-base",
-        "tripleoclient",
-        "tripleo-ui"
-    ],
-    'oraclelinux+binary': [
-        "almanach-base",
-        "bifrost-base",
-        "blazar-base",
-        "crane",
-        "cyborg-base",
-        "dragonflow-base",
-        "freezer-base",
-        "karbor-base",
-        "kuryr-base",
-        "monasca-base",
-        "monasca-thresh",
-        "mongodb",
-        "nova-mksproxy",
-        "ovsdpdk",
-        "rsyslog",
-        "searchlight-base",
-        "solum-base",
-        "tripleoclient",
-        "vmtp",
-        "zun-base"
-    ],
-    'oraclelinux+source': [
-        "bifrost-base",
-        "mongodb",
-        "ovsdpdk",
-        "rsyslog",
-        "tripleoclient",
-        # TODO(jeffrey4l): remove tripleo-ui when following bug is fixed
-        # https://bugs.launchpad.net/tripleo/+bug/1744215
-        "tripleo-ui"
-    ]
+    },
 }
 
 
@@ -362,8 +357,8 @@ class PushTask(DockerTask):
             self.logger.exception('Unknown error when pushing')
             image.status = STATUS_PUSH_ERROR
         finally:
-            if (image.status not in STATUS_ERRORS
-                    and image.status != STATUS_UNPROCESSED):
+            if (image.status not in STATUS_ERRORS and
+                    image.status != STATUS_UNPROCESSED):
                 self.logger.info('Pushed successfully')
                 self.success = True
             else:
@@ -550,7 +545,7 @@ class BuildTask(DockerTask):
 
         self.logger.debug('Processing')
 
-        if image.status == STATUS_SKIPPED:
+        if image.status in [STATUS_SKIPPED, STATUS_UNBUILDABLE]:
             self.logger.info('Skipping %s' % image.name)
             return
 
@@ -565,7 +560,8 @@ class BuildTask(DockerTask):
             return
 
         image.status = STATUS_BUILDING
-        self.logger.info('Building')
+        image.start = datetime.datetime.now()
+        self.logger.info('Building started at %s' % image.start)
 
         if image.source and 'source' in image.source:
             self.process_source(image, image.source)
@@ -630,7 +626,9 @@ class BuildTask(DockerTask):
             self.logger.exception('Unknown error when building')
         else:
             image.status = STATUS_BUILT
-            self.logger.info('Built')
+            now = datetime.datetime.now()
+            self.logger.info('Built at %s (took %s)' %
+                             (now, now - image.start))
 
     def squash(self):
         image_tag = self.image.canonical_name
@@ -713,11 +711,12 @@ class KollaWorker(object):
         elif self.base_arch == 'ppc64le':
             self.debian_arch = 'ppc64el'
         self.images = list()
+        self.openstack_release = conf.openstack_release
         rpm_setup_config = ([repo_file for repo_file in
                              conf.rpm_setup_config if repo_file is not None])
         self.rpm_setup = self.build_rpm_setup(rpm_setup_config)
 
-        rh_base = ['centos', 'oraclelinux', 'rhel']
+        rh_base = ['centos', 'rhel']
         rh_type = ['source', 'binary', 'rdo', 'rhos']
         deb_base = ['ubuntu', 'debian']
         deb_type = ['source', 'binary']
@@ -726,6 +725,10 @@ class KollaWorker(object):
             self.conf.distro_python_version = "2.7"
         elif self.base in rh_base and self.base_tag.startswith('8'):
             self.conf.distro_python_version = "3.6"
+        elif self.base in ['debian']:
+            self.conf.distro_python_version = "3.7"
+        elif self.base in ['ubuntu']:
+            self.conf.distro_python_version = "3.6"
         else:
             # Assume worst
             self.conf.distro_python_version = "2.7"
@@ -779,6 +782,7 @@ class KollaWorker(object):
         self.image_statuses_good = dict()
         self.image_statuses_unmatched = dict()
         self.image_statuses_skipped = dict()
+        self.image_statuses_unbuildable = dict()
         self.maintainer = conf.maintainer
         self.distro_python_version = conf.distro_python_version
 
@@ -787,10 +791,10 @@ class KollaWorker(object):
             self.dc = docker.APIClient(version='auto', **docker_kwargs)
         except docker.errors.DockerException as e:
             self.dc = None
-            if not (conf.template_only
-                    or conf.save_dependency
-                    or conf.list_images
-                    or conf.list_dependencies):
+            if not (conf.template_only or
+                    conf.save_dependency or
+                    conf.list_images or
+                    conf.list_dependencies):
                 LOG.error("Unable to connect to Docker, exiting")
                 LOG.info("Exception caught: {0}".format(e))
                 sys.exit(1)
@@ -954,6 +958,7 @@ class KollaWorker(object):
                       'image_prefix': self.image_prefix,
                       'install_type': self.install_type,
                       'namespace': self.namespace,
+                      'openstack_release': self.openstack_release,
                       'tag': self.tag,
                       'maintainer': self.maintainer,
                       'kolla_version': kolla_version,
@@ -1038,37 +1043,80 @@ class KollaWorker(object):
                 else:
                     filter_ += self.conf.profiles[profile]
 
+        # mark unbuildable images and their children
+        tag_element = r'(%s|%s|%s)' % (self.base,
+                                       self.install_type,
+                                       self.base_arch)
+        tag_re = re.compile(r'^%s(\+%s)*$' % (tag_element, tag_element))
+        unbuildable_images = set()
+        for set_tag in UNBUILDABLE_IMAGES:
+            if tag_re.match(set_tag):
+                unbuildable_images.update(UNBUILDABLE_IMAGES[set_tag])
+
+        if unbuildable_images:
+            for image in self.images:
+                if image.name in unbuildable_images:
+                    image.status = STATUS_UNBUILDABLE
+                else:
+                    # let's check ancestors
+                    # if any of them is unbuildable then we mark it
+                    # and then mark image
+                    build_image = True
+                    ancestor_image = image
+                    while (ancestor_image.parent is not None):
+                        ancestor_image = ancestor_image.parent
+                        if ancestor_image.name in unbuildable_images or \
+                           ancestor_image.status == STATUS_UNBUILDABLE:
+                            build_image = False
+                            ancestor_image.status = STATUS_UNBUILDABLE
+                            break
+                    if not build_image:
+                        image.status = STATUS_UNBUILDABLE
+
+        # When we want to build a subset of images then filter_ part kicks in.
+        # Otherwise we just mark everything buildable as matched for build.
+
         if filter_:
             patterns = re.compile(r"|".join(filter_).join('()'))
             for image in self.images:
-                if image.status in (STATUS_MATCHED, STATUS_SKIPPED):
+                # as we now list not buildable/skipped images we need to
+                # process them otherwise list will contain also not requested
+                # entries
+                if image.status == STATUS_MATCHED:
                     continue
                 if re.search(patterns, image.name):
-                    image.status = STATUS_MATCHED
-                    while (image.parent is not None and
-                           image.parent.status not in (STATUS_MATCHED,
-                                                       STATUS_SKIPPED)):
-                        image = image.parent
+                    if image.status not in [STATUS_SKIPPED,
+                                            STATUS_UNBUILDABLE]:
+                        image.status = STATUS_MATCHED
+
+                    # skip image if --skip-existing was given and image
+                    # was already built
+                    if (self.conf.skip_existing and image.in_docker_cache()):
+                        image.status = STATUS_SKIPPED
+
+                    # handle image ancestors
+                    ancestor_image = image
+                    while (ancestor_image.parent is not None and
+                           ancestor_image.parent.status not in
+                           (STATUS_MATCHED, STATUS_SKIPPED)):
+                        ancestor_image = ancestor_image.parent
                         if self.conf.skip_parents:
-                            image.status = STATUS_SKIPPED
+                            ancestor_image.status = STATUS_SKIPPED
                         elif (self.conf.skip_existing and
-                              image.in_docker_cache()):
-                            image.status = STATUS_SKIPPED
+                              ancestor_image.in_docker_cache()):
+                            ancestor_image.status = STATUS_SKIPPED
                         else:
-                            image.status = STATUS_MATCHED
+                            if ancestor_image.status != STATUS_UNBUILDABLE:
+                                ancestor_image.status = STATUS_MATCHED
                         LOG.debug('Image %s matched regex', image.name)
                 else:
+                    # we do not care if it is skipped or not as we did not
+                    # request it
                     image.status = STATUS_UNMATCHED
         else:
             for image in self.images:
-                image.status = STATUS_MATCHED
-
-        skipped_images = SKIPPED_IMAGES.get('%s+%s' % (self.base,
-                                                       self.install_type))
-        if skipped_images:
-            for image in self.images:
-                if image.name in skipped_images:
-                    image.status = STATUS_UNMATCHED
+                if image.status != STATUS_UNBUILDABLE:
+                    image.status = STATUS_MATCHED
 
     def summary(self):
         """Walk the dictionary of images statuses and print results."""
@@ -1084,6 +1132,7 @@ class KollaWorker(object):
             'failed': [],
             'not_matched': [],
             'skipped': [],
+            'unbuildable': [],
         }
 
         if self.image_statuses_good:
@@ -1128,26 +1177,38 @@ class KollaWorker(object):
                 })
 
         if self.image_statuses_skipped:
-            LOG.debug("================================")
-            LOG.debug("Images skipped due build options")
-            LOG.debug("================================")
+            LOG.info("===================================")
+            LOG.info("Images skipped due to build options")
+            LOG.info("===================================")
             for name in sorted(self.image_statuses_skipped.keys()):
-                LOG.debug(name)
+                LOG.info(name)
                 results['skipped'].append({
                     'name': name,
                 })
 
+        if self.image_statuses_unbuildable:
+            LOG.info("=========================================")
+            LOG.info("Images not buildable due to build options")
+            LOG.info("=========================================")
+            for name in sorted(self.image_statuses_unbuildable.keys()):
+                LOG.info(name)
+                results['unbuildable'].append({
+                    'name': name,
+                })
+
         return results
 
     def get_image_statuses(self):
         if any([self.image_statuses_bad,
                 self.image_statuses_good,
                 self.image_statuses_unmatched,
-                self.image_statuses_skipped]):
+                self.image_statuses_skipped,
+                self.image_statuses_unbuildable]):
             return (self.image_statuses_bad,
                     self.image_statuses_good,
                     self.image_statuses_unmatched,
-                    self.image_statuses_skipped)
+                    self.image_statuses_skipped,
+                    self.image_statuses_unbuildable)
         for image in self.images:
             if image.status == STATUS_BUILT:
                 self.image_statuses_good[image.name] = image.status
@@ -1155,12 +1216,15 @@ class KollaWorker(object):
                 self.image_statuses_unmatched[image.name] = image.status
             elif image.status == STATUS_SKIPPED:
                 self.image_statuses_skipped[image.name] = image.status
+            elif image.status == STATUS_UNBUILDABLE:
+                self.image_statuses_unbuildable[image.name] = image.status
             else:
                 self.image_statuses_bad[image.name] = image.status
         return (self.image_statuses_bad,
                 self.image_statuses_good,
                 self.image_statuses_unmatched,
-                self.image_statuses_skipped)
+                self.image_statuses_skipped,
+                self.image_statuses_unbuildable)
 
     def build_image_list(self):
         def process_source_installation(image, section):
@@ -1316,12 +1380,15 @@ class KollaWorker(object):
         queue = six.moves.queue.Queue()
 
         for image in self.images:
-            if image.status in (STATUS_UNMATCHED, STATUS_SKIPPED):
+            if image.status in (STATUS_UNMATCHED, STATUS_SKIPPED,
+                                STATUS_UNBUILDABLE):
                 # Don't bother queuing up build tasks for things that
                 # were not matched in the first place... (not worth the
                 # effort to run them, if they won't be used anyway).
                 continue
-            if image.parent is None:
+            # Build all root nodes, where a root is defined as having no parent
+            # or having a parent that is explicitly being skipped.
+            if image.parent is None or image.parent.status == STATUS_SKIPPED:
                 queue.put(BuildTask(self.conf, image, push_queue))
                 LOG.info('Added image %s to queue', image.name)
 
