@@ -20,9 +20,10 @@ from oslo_log import log as logging
 from oslotest import base
 import testtools
 
+
 sys.path.append(
     os.path.abspath(os.path.join(os.path.dirname(__file__), '../tools')))
-from kolla.image import build
+from kolla.image import build  # noqa
 
 LOG = logging.getLogger(__name__)
 
@@ -47,19 +48,19 @@ class BuildTest(object):
         with patch.object(sys, 'argv', self.build_args):
             LOG.info("Running with args %s", self.build_args)
             (bad_results, good_results, unmatched_results,
-             skipped_results) = build.run_build()
+             skipped_results, unbuildable_results) = build.run_build()
 
         failures = 0
         for image, result in bad_results.items():
-            if result is not 'error':
+            if result != 'error':
                 continue
             failures = failures + 1
             LOG.critical(">>> Expected image '%s' to succeed!", image)
 
-        for image in unmatched_results.keys():
+        for image in unmatched_results:
             LOG.warning(">>> Image '%s' was not matched", image)
 
-        self.assertEqual(failures, 0, "%d failure(s) occurred" % failures)
+        self.assertEqual(0, failures, "%d failure(s) occurred" % failures)
 
 
 class BuildTestCentosBinary(BuildTest, base.BaseTestCase):
@@ -110,22 +111,6 @@ class BuildTestDebianSource(BuildTest, base.BaseTestCase):
                                 "--type", "source"])
 
 
-class BuildTestOracleLinuxBinary(BuildTest, base.BaseTestCase):
-
-    def setUp(self):
-        super(BuildTestOracleLinuxBinary, self).setUp()
-        self.build_args.extend(["--base", "oraclelinux",
-                                "--type", "binary"])
-
-
-class BuildTestOracleLinuxSource(BuildTest, base.BaseTestCase):
-
-    def setUp(self):
-        super(BuildTestOracleLinuxSource, self).setUp()
-        self.build_args.extend(["--base", "oraclelinux",
-                                "--type", "source"])
-
-
 class DeployTestCentosBinary(BuildTestCentosBinary):
 
     def setUp(self):
@@ -140,20 +125,6 @@ class DeployTestCentosSource(BuildTestCentosSource):
         self.build_args.extend(["--profile", "gate"])
 
 
-class DeployTestOracleLinuxBinary(BuildTestOracleLinuxBinary):
-
-    def setUp(self):
-        super(DeployTestOracleLinuxBinary, self).setUp()
-        self.build_args.extend(["--profile", "gate"])
-
-
-class DeployTestOracleLinuxSource(BuildTestOracleLinuxSource):
-
-    def setUp(self):
-        super(DeployTestOracleLinuxSource, self).setUp()
-        self.build_args.extend(["--profile", "gate"])
-
-
 class DeployTestUbuntuBinary(BuildTestUbuntuBinary):
 
     def setUp(self):
